|LinuxTests|_ |WinTests|_ |Coverage|_ |PyPIVersion|_ |PyVersion|_ |License|_

Param
=====

Param is a library providing Parameters: Python attributes extended to
have features such as type and range checking, dynamically generated
values, documentation strings, default values, etc., each of which is
inherited from parent classes if not specified in a subclass.

Param contains only two required Python files, with no external
dependencies, and is provided freely for both non-commercial and
commercial use under a BSD license, so that it can easily be included
as part of other projects.

Please see `param's website <http://param.holoviz.org>`_ for
official releases, installation instructions, documentation, and examples.

.. |LinuxTests| image:: https://travis-ci.org/holoviz/param.svg?branch=master
.. _LinuxTests: https://travis-ci.org/holoviz/param

.. |WinTests| image:: https://ci.appveyor.com/api/projects/status/jv1j2036g0a5t5qx/branch/master?svg=true
.. _WinTests: https://ci.appveyor.com/project/holoviz-developers/param/branch/master

.. |Coverage| image:: https://coveralls.io/repos/github/holoviz/param/badge.svg?branch=master
.. _Coverage: https://coveralls.io/github/holoviz/param?branch=master

.. |PyPIVersion| image:: http://img.shields.io/pypi/v/param.svg
.. _PyPIVersion: https://pypi.python.org/pypi/param

.. |PyVersion| image:: https://img.shields.io/pypi/pyversions/param.svg
.. _PyVersion: https://pypi.python.org/pypi/param

.. |License| image:: https://img.shields.io/pypi/l/param.svg
.. _License: https://pypi.python.org/pypi/param
